==> netbeans_8.0.2+dfsg1.orig.tar.xz: netbeans-8.0.2/web.client.samples/src/org/netbeans/modules/web/client/samples/wizard/iterator/OnlineSiteTemplate.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2012 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2012 Sun Microsystems, Inc.
 */
package org.netbeans.modules.web.client.samples.wizard.iterator;

import org.netbeans.modules.web.clientproject.api.sites.SiteHelper;
import java.awt.EventQueue;
import java.io.File;
import java.io.IOException;
import java.util.logging.Logger;
import org.netbeans.api.progress.ProgressHandle;
import org.netbeans.modules.web.clientproject.api.network.NetworkException;
import org.netbeans.modules.web.clientproject.api.network.NetworkSupport;
import org.netbeans.modules.web.clientproject.createprojectapi.CreateProjectProperties;
import org.openide.filesystems.FileObject;


public class OnlineSiteTemplate {

    private static final Logger LOGGER = Logger.getLogger(OnlineSiteTemplate.class.getName());

    private final String name;
    private final String url;
    private final File libFile;

    public OnlineSiteTemplate(String name, String url, String zipName) {
        this.name = name;
        this.url = url;
        this.libFile = new File(SiteHelper.getJsLibsDirectory(), zipName);
    }

    public String getName() {
        return name;
    }

    public boolean isPrepared() {
        return libFile.isFile();
    }

    public void prepare() throws NetworkException, IOException, InterruptedException {
        assert !EventQueue.isDispatchThread();
        assert !isPrepared();
        NetworkSupport.download(url, libFile);
    }

    public void configure(CreateProjectProperties projectProperties) {
    }

    public final void apply(FileObject projectDir, CreateProjectProperties projectProperties, ProgressHandle handle) throws IOException {
        assert !EventQueue.isDispatchThread();
        if (!isPrepared()) {
            // not correctly prepared, user has to know about it already
            LOGGER.info("Template not correctly prepared, nothing to be applied"); //NOI18N
            return;
        }
        SiteHelper.unzipProjectTemplate(getTargetDir(projectDir, projectProperties), libFile, handle);
    }

    protected FileObject getTargetDir(FileObject projectDir, CreateProjectProperties projectProperties) {
        // by default, extract template to site root
        return projectDir.getFileObject(projectProperties.getSiteRootFolder());
    }
}

==> netbeans_8.1+dfsg2.orig.tar.xz: netbeans-8.1/web.client.samples/src/org/netbeans/modules/web/client/samples/wizard/iterator/OnlineSiteTemplate.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2012 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2012 Sun Microsystems, Inc.
 */
package org.netbeans.modules.web.client.samples.wizard.iterator;

import org.netbeans.modules.web.clientproject.api.sites.SiteHelper;
import java.awt.EventQueue;
import java.io.File;
import java.io.IOException;
import java.util.logging.Logger;
import org.netbeans.api.progress.ProgressHandle;
import org.netbeans.modules.web.clientproject.api.network.NetworkException;
import org.netbeans.modules.web.clientproject.api.network.NetworkSupport;
import org.netbeans.modules.web.clientproject.createprojectapi.CreateProjectProperties;
import org.openide.filesystems.FileObject;


public class OnlineSiteTemplate {

    private static final Logger LOGGER = Logger.getLogger(OnlineSiteTemplate.class.getName());

    private final String name;
    private final String url;
    private final File libFile;

    public OnlineSiteTemplate(String name, String url, String zipName) {
        this.name = name;
        this.url = url;
        this.libFile = new File(SiteHelper.getJsLibsDirectory(), zipName);
    }

    public String getName() {
        return name;
    }

    public boolean isPrepared() {
        return libFile.isFile();
    }

    public void prepare() throws NetworkException, IOException, InterruptedException {
        assert !EventQueue.isDispatchThread();
        assert !isPrepared();
        NetworkSupport.download(url, libFile);
    }

    public void configure(CreateProjectProperties projectProperties) {
        projectProperties.setSiteRootFolder("public_html") // NOI18N
                .setTestFolder("test") // NOI18N
                .setStartFile("index.html"); // NOI18N
    }

    public final void apply(FileObject projectDir, CreateProjectProperties projectProperties, ProgressHandle handle) throws IOException {
        assert !EventQueue.isDispatchThread();
        if (!isPrepared()) {
            // not correctly prepared, user has to know about it already
            LOGGER.info("Template not correctly prepared, nothing to be applied"); //NOI18N
            return;
        }
        SiteHelper.unzipProjectTemplate(getTargetDir(projectDir, projectProperties), libFile, handle);
    }

    protected FileObject getTargetDir(FileObject projectDir, CreateProjectProperties projectProperties) {
        // by default, extract template to site root
        return projectDir.getFileObject(projectProperties.getSiteRootFolder());
    }
}
